type BBox = [left: number, bottom: number, right: number, top: number];
type XYZ = [x: number, y: number, z: number];
type Value = string | number | boolean | null;
type Properties = Record<string, Value>;
type Sources = '900913' | 'WGS84';
interface FeatureCollection {
    type: 'FeatureCollection';
    features: Feature[];
}
interface Feature {
    type: 'Feature';
    id?: number;
    properties: Properties;
    geometry: Geometry;
}
type GeometryType = 'Point' | 'MultiPoint' | 'LineString' | 'MultiLineString' | 'Polygon' | 'MultiPolygon';
type Geometry = PointGeometry | MultiPointGeometry | LineStringGeometry | MultiLineStringGeometry | PolygonGeometry | MultiPolygonGeometry;
type Point = [x: number, y: number];
type MultiPoint = Point[];
type LineString = Point[];
type MultiLineString = LineString[];
type Polygon = Point[][];
type MultiPolygon = Polygon[];
interface PointGeometry {
    type: 'Point';
    coordinates: Point;
}
interface MultiPointGeometry {
    type: 'MultiPoint';
    coordinates: MultiPoint;
}
interface LineStringGeometry {
    type: 'LineString';
    coordinates: LineString;
}
interface MultiLineStringGeometry {
    type: 'MultiLineString';
    coordinates: MultiLineString;
}
interface PolygonGeometry {
    type: 'Polygon';
    coordinates: Polygon;
}
interface MultiPolygonGeometry {
    type: 'MultiPolygon';
    coordinates: MultiPolygon;
}

export { BBox, Feature, FeatureCollection, Geometry, GeometryType, LineString, LineStringGeometry, MultiLineString, MultiLineStringGeometry, MultiPoint, MultiPointGeometry, MultiPolygon, MultiPolygonGeometry, Point, PointGeometry, Polygon, PolygonGeometry, Properties, Sources, Value, XYZ };
